import { UsePopperOptions } from '@udecode/plate-ui-popper';
import { StateActions, StoreApi } from '@udecode/zustood';
import { Range } from 'slate';
import { NoData, TComboboxItem } from './components';
import { ComboboxOnSelectItem } from './types';
export declare type ComboboxStateById<TData = NoData> = {
    /**
     * Combobox id.
     */
    id: string;
    /**
     * Items filter function by text.
     * @default (value) => value.text.toLowerCase().startsWith(search.toLowerCase())
     */
    filter?: (search: string) => (item: TComboboxItem<TData>) => boolean;
    /**
     * Max number of items.
     * @default items.length
     */
    maxSuggestions?: number;
    /**
     * Trigger that activates the combobox.
     */
    trigger: string;
    /**
     * Regular expression for search, for example to allow whitespace
     */
    searchPattern?: string;
    /**
     * Called when an item is selected.
     */
    onSelectItem: ComboboxOnSelectItem<TData> | null;
    /**
     * Is opening/closing the combobox controlled by the client.
     */
    controlled?: boolean;
};
export declare type ComboboxStoreById<TData = NoData> = StoreApi<string, ComboboxStateById<TData>, StateActions<ComboboxStateById<TData>>>;
export declare type ComboboxState<TData = NoData> = {
    /**
     * Active id (combobox id which is opened).
     */
    activeId: string | null;
    /**
     * Object whose keys are combobox ids and values are config stores
     * (e.g. one for tag, one for mention,...).
     */
    byId: Record<string, ComboboxStoreById>;
    /**
     * Unfiltered items.
     */
    items: TComboboxItem<TData>[];
    /**
     * Filtered items
     */
    filteredItems: TComboboxItem<TData>[];
    /**
     * Highlighted index.
     */
    highlightedIndex: number;
    /**
     * Parent element of the popper element (the one that has the scroll).
     * @default document
     */
    popperContainer?: Document | HTMLElement;
    /**
     * Overrides `usePopper` options.
     */
    popperOptions?: UsePopperOptions;
    /**
     * Range from the trigger to the cursor.
     */
    targetRange: Range | null;
    /**
     * Text after the trigger.
     */
    text: string | null;
};
export declare const comboboxStore: StoreApi<"combobox", ComboboxState<undefined>, import("@udecode/zustood").SetRecord<ComboboxState<undefined>> & {
    state: import("@udecode/zustood").SetImmerState<ComboboxState<undefined>>;
    mergeState: import("@udecode/zustood").MergeState<ComboboxState<undefined>>;
} & {
    setComboboxById: <TData = undefined>(state: ComboboxStateById<TData>) => void;
    open: (state: Pick<ComboboxState, 'activeId' | 'targetRange' | 'text'>) => void;
    reset: () => void;
}, {
    isOpen: () => boolean;
}>;
export declare const getComboboxStoreById: (id: string | null) => ComboboxStoreById<undefined> | null;
export declare const useActiveComboboxStore: () => ComboboxStoreById<undefined> | null;
//# sourceMappingURL=combobox.store.d.ts.map